<?php
session_start();
// Enable error reporting for development
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Start output buffering
ob_start();

require_once '../datab.php';

// Set JSON header
header('Content-Type: application/json');

try {
    // Set current datetime
    $dateTime = date("Y-m-d H:i:s");
    $expiryDate = date('Y-m-d H:i:s', strtotime('+1 month'));

    // Helper to sanitize input
    function sanitizeInput($conn, $input) {
        return mysqli_real_escape_string($conn, trim($input));
    }

    // List of fields to capture
    $fields = [
        'driver_name', 'wa_no', 'alt_no', 'upi_no', 'current_address', 'permanent_address',
        'area', 'aadhaar', 'driver_type', 'driver_category', 'blood_group',
        'doj', 'ref_by', 'license_no', 'license_issue_date', 'license_expiry',
        'license_type', 'license_type_exp', 'emergency_name', 'emergency_no', 'emergency_relation',
        'grace_period', 'subscription_type'
    ];

    // Sanitize all fields
    $data = [];
    foreach ($fields as $field) {
        $data[$field] = sanitizeInput($conn, $_POST[$field] ?? '');
    }

    // Insert new driver data
    $insert_sql = "INSERT INTO driver_data (
        driver_name, wa_no, alt_no, upi_no, current_address, permanent_address, area, aadhaar,
        driver_type, driver_category, blood_group, doj, ref_by,
        license_no, license_issue_date, license_expiry, license_type, license_type_exp,
        emergency_name, emergency_no, emergency_relation,
        grace_period, created_by, dateTime, status, subscription, subscription_type, 
        last_sub_date, expiry_date
    ) VALUES (
        '{$data['driver_name']}', '{$data['wa_no']}', '{$data['alt_no']}', '{$data['upi_no']}',
        '{$data['current_address']}', '{$data['permanent_address']}', '{$data['area']}', '{$data['aadhaar']}',
        '{$data['driver_type']}', '{$data['driver_category']}', '{$data['blood_group']}',
        '{$data['doj']}', '{$data['ref_by']}', '{$data['license_no']}', '{$data['license_issue_date']}',
        '{$data['license_expiry']}', '{$data['license_type']}', '{$data['license_type_exp']}',
        '{$data['emergency_name']}', '{$data['emergency_no']}', '{$data['emergency_relation']}',
        '{$data['grace_period']}', '$dateTime', '$dateTime', 'Active', 'Active', '{$data['subscription_type']}', 
        '$dateTime', '$expiryDate'
    )";

    $insert_result = mysqli_query($conn, $insert_sql);

    if (!$insert_result) {
        throw new Exception('Failed to insert driver data: ' . mysqli_error($conn));
    }

    // Get new driver ID
    $driver_id = mysqli_insert_id($conn);

    // Create upload folder
    $upload_dir = "../driver/documents/$driver_id/";
    if (!is_dir($upload_dir)) {
        mkdir($upload_dir, 0777, true);
    }

    // Handle file uploads
    $uploaded_files = [];
    $file_fields = [
        'photo' => 'photo',
        'license_proof' => 'license_proof',
        'aadhaar_proof' => 'aadhaar_proof',
        'current_address_proof' => 'current_address_proof',
        'permanent_address_proof' => 'permanent_address_proof'
    ];

    foreach ($file_fields as $db_field => $input_name) {
        if (!empty($_FILES[$input_name]['name']) && $_FILES[$input_name]['error'] === 0) {
            $file_tmp = $_FILES[$input_name]['tmp_name'];
            $file_name = basename($_FILES[$input_name]['name']);
            $target_path = $upload_dir . $file_name;

            if (move_uploaded_file($file_tmp, $target_path)) {
                $uploaded_files[$db_field] = sanitizeInput($conn, $file_name);
            }
        }
    }

    // Update driver_data with file names
    if (!empty($uploaded_files)) {
        $update_parts = [];
        foreach ($uploaded_files as $col => $val) {
            $update_parts[] = "$col = '$val'";
        }
        $update_sql = "UPDATE driver_data SET " . implode(", ", $update_parts) . " WHERE id = $driver_id";
        mysqli_query($conn, $update_sql);
    }

    // Return success response
    ob_end_clean();
    $_SESSION['success_message'] = 'Driver created successfully';
    echo json_encode([
        'status' => 'Success',
        'message' => 'Driver created successfully',
        'redirect' => '../pages/driver_list.php',
        'driver_id' => $driver_id
    ]);
    exit;

} catch (Exception $e) {
    ob_end_clean();
    http_response_code(500);
    echo json_encode([
        'status' => 'Error',
        'message' => $e->getMessage()
    ]);
    exit;
}
?>
