<?php
session_start();
ob_start();

include 'datab.php';

header('Content-Type: application/json');
$response = ['status' => '', 'message' => ''];

if (!isset($_POST['id']) || !is_numeric($_POST['id'])) {
    $response['status'] = 'error';
    $response['message'] = 'Invalid or missing ID.';
    echo json_encode($response);
    exit;
}

$driver_id = $_POST['id'];
$available_range = $_POST['available_date'] ?? '';
$area = $_POST['area'] ?? '';
$comments = $_POST['comments'] ?? '';
$status = 'Active';
$currentDateTime = date('Y-m-d H:i:s');

// Handle range split from Flatpickr
$dateParts = explode(' to ', $available_range);
if (count($dateParts) !== 2) {
    $response['status'] = 'error';
    $response['message'] = 'Invalid date range format.';
    echo json_encode($response);
    exit;
}

// Convert to datetime
$startDateTime = date('Y-m-d H:i:s', strtotime($dateParts[0]));
$endDateTime = date('Y-m-d H:i:s', strtotime($dateParts[1]));

// Format for visible `available_date` (just dates)
$startDateOnly = date('Y-m-d', strtotime($dateParts[0]));
$endDateOnly = date('Y-m-d', strtotime($dateParts[1]));
$availableDateString = "$startDateOnly - $endDateOnly";

// Insert into DB
$insertQuery = "INSERT INTO available_driver_data 
    (driver_id, start_datetime, end_datetime, available_date, area, comments, status, dateTime) 
    VALUES (?, ?, ?, ?, ?, ?, ?, ?)";
$insertStmt = $conn->prepare($insertQuery);

if (!$insertStmt) {
    $response['status'] = 'error';
    $response['message'] = 'Prepare failed: ' . $conn->error;
    echo json_encode($response);
    exit;
}

$insertStmt->bind_param("isssssss", $driver_id, $startDateTime, $endDateTime, $availableDateString, $area, $comments, $status, $currentDateTime);

    ob_end_clean();
    $_SESSION['success_message'] = 'Driver availability updated successfully';

if ($insertStmt->execute()) {
    $_SESSION['success_message'] = "Driver availability updated successfully.";
    $response['status'] = 'success';
    $response['message'] = 'Driver availability saved.';
} else {
    $response['status'] = 'error';
    $response['message'] = 'Insert failed: ' . $insertStmt->error;
}

$insertStmt->close();
$conn->close();

echo json_encode($response);
// session_start();
// include 'datab.php';

// header('Content-Type: application/json');
// $response = ['status' => '', 'message' => ''];

// if (!isset($_POST['id']) || !is_numeric($_POST['id'])) {
//     $response['status'] = 'error';
//     $response['message'] = 'Invalid or missing ID.';
//     echo json_encode($response);
//     exit;
// }

// $driver_id = $_POST['id'];
// $available_range = $_POST['available_date'] ?? '';
// $area = $_POST['area'] ?? '';
// $comments = $_POST['comments'] ?? '';
// $status = 'Active';
// $currentDateTime = date('Y-m-d H:i:s');

// // Correct delimiter based on Flatpickr: ' to '
// $dateParts = explode(' to ', $available_range);
// if (count($dateParts) !== 2) {
//     $response['status'] = 'error';
//     $response['message'] = 'Invalid date range format.';
//     echo json_encode($response);
//     exit;
// }

// $startDate = date('Y-m-d H:i:s', strtotime($dateParts[0]));
// $endDate = date('Y-m-d H:i:s', strtotime($dateParts[1]));

// $insertQuery = "INSERT INTO available_driver_data (driver_id, start_datetime, end_datetime, area, comments, status, dateTime) 
//                 VALUES (?, ?, ?, ?, ?, ?, ?)";
// $insertStmt = $conn->prepare($insertQuery);

// if (!$insertStmt) {
//     $response['status'] = 'error';
//     $response['message'] = 'Prepare failed: ' . $conn->error;
//     echo json_encode($response);
//     exit;
// }

// $insertStmt->bind_param("issssss", $driver_id, $startDate, $endDate, $area, $comments, $status, $currentDateTime);

// if ($insertStmt->execute()) {
//     $_SESSION['success_message'] = "Availability updated successfully.";
//     $response['status'] = 'success';
//     $response['message'] = 'Driver availability saved.';
// } else {
//     $response['status'] = 'error';
//     $response['message'] = 'Insert failed: ' . $insertStmt->error;
// }

// $insertStmt->close();
// $conn->close();

// echo json_encode($response);

// session_start();
// include 'datab.php'; // DB connection

// header('Content-Type: application/json');

// $response = ['status' => '', 'message' => ''];

// // Validate input
// if (!isset($_POST['id']) || !is_numeric($_POST['id'])) {
//     $response['status'] = 'error';
//     $response['message'] = 'Invalid or missing ID.';
//     echo json_encode($response);
//     exit;
// }

// // Collect data
// $driver_id = $_POST['id'];
// $available_date = $_POST['available_date'] ?? '';
// $area = $_POST['area'] ?? '';
// $comments = $_POST['comments'] ?? '';

// // Prepare INSERT
// $insertQuery = "INSERT INTO available_driver_data (driver_id, available_date, area, comments) VALUES (?, ?, ?, ?)";
// $insertStmt = $conn->prepare($insertQuery);

// if (!$insertStmt) {
//     $response['status'] = 'error';
//     $response['message'] = 'Prepare failed: ' . $conn->error;
//     echo json_encode($response);
//     exit;
// }

// $insertStmt->bind_param("isss", $driver_id, $available_date, $area, $comments);

// if ($insertStmt->execute()) {
//     $_SESSION['success_message'] = "Availability updated successfully.";
//     $response['status'] = 'success';
//     $response['message'] = 'Driver availability saved.';
// } else {
//     $response['status'] = 'error';
//     $response['message'] = 'Insert failed: ' . $insertStmt->error;
// }

// $insertStmt->close();
// $conn->close();

// echo json_encode($response);
?>
